@@ -2,3 +2,6 @@ from .condition import Condition
 from .tools import peer, random_id
 from .vk import Auth, Keyboard
 from .exception import VkErr
+from .payload import payload
+from .DotDict import DotDict
+from .cond import *
